# SPDX-FileCopyrightText: 2025-present Faria22 <fariafelipe22@hotmail.com>
#
# SPDX-License-Identifier: MIT
from .get_example_files import acrolein, benzene, co, co2, furan, h2o, o2, prismane, pyridine

__all__ = ['acrolein', 'benzene', 'co', 'co2', 'furan', 'h2o', 'o2', 'prismane', 'pyridine']
